@@ -16,12 +16,16 @@
 """
 This module configures the global fastapi application
 """
+import fileinput
+import glob
 import inspect
+import logging
 import os
-import sys
-import warnings
+import shutil
+import tempfile
 from pathlib import Path
 
+import backoff
 from brotli_asgi import BrotliMiddleware
 from fastapi import FastAPI
 from fastapi.exceptions import RequestValidationError
@@ -30,10 +34,8 @@ from pydantic import ConfigError
 
 from argilla import __version__ as argilla_version
 from argilla.logging import configure_logging
-from argilla.server.daos.backend.elasticsearch import (
-    ElasticsearchBackend,
-    GenericSearchError,
-)
+from argilla.server.daos.backend import GenericElasticEngineBackend
+from argilla.server.daos.backend.base import GenericSearchError
 from argilla.server.daos.datasets import DatasetsDAO
 from argilla.server.daos.records import DatasetRecordsDAO
 from argilla.server.errors import APIErrorHandler, EntityNotFoundError
@@ -42,6 +44,8 @@ from argilla.server.security import auth
 from argilla.server.settings import settings
 from argilla.server.static_rewrite import RewriteStaticFiles
 
+_LOGGER = logging.getLogger("argilla")
+
 
 def configure_middleware(app: FastAPI):
     """Configures fastapi middleware"""
@@ -73,15 +77,43 @@ def configure_api_router(app: FastAPI):
 
 def configure_app_statics(app: FastAPI):
     """Configure static folder for app"""
+
     parent_path = Path(__file__).parent.absolute()
     statics_folder = Path(os.path.join(parent_path, "static"))
     if not (statics_folder.exists() and statics_folder.is_dir()):
         return
 
+    def _create_statics_folder(path_from):
+        """
+        Application statics will be created with a parameterized baseUrl variable.
+
+        This function will replace the variable by the real runtime value found in settings.base_url
+
+        This allow us to deploy the argilla server under a custom base url, even when webapp does not
+        support it.
+
+        """
+        BASE_URL_VAR_NAME = "@@baseUrl@@"
+        temp_dir = tempfile.mkdtemp()
+        new_folder = shutil.copytree(path_from, temp_dir + "/statics")
+        for extension in ["*.js", "*.html"]:
+            for file in glob.glob(
+                f"{new_folder}/**/{extension}",
+                recursive=True,
+            ):
+                with fileinput.FileInput(file, inplace=True, backup=".bak") as file:
+                    for line in file:
+                        base_url = settings.base_url.removesuffix("/")
+                        print(line.replace(BASE_URL_VAR_NAME, base_url), end="")
+
+        return new_folder
+
+    temp_statics = _create_statics_folder(statics_folder)
+
     app.mount(
         "/",
         RewriteStaticFiles(
-            directory=statics_folder,
+            directory=temp_statics,
             html=True,
             check_dir=False,
         ),
@@ -89,14 +121,26 @@ def configure_app_statics(app: FastAPI):
     )
 
 
-def configure_app_storage(app: FastAPI):
-    @app.on_event("startup")
-    async def configure_elasticsearch():
+def configure_storage(app: FastAPI):
+    def _on_backoff(event):
+        _LOGGER.warning(
+            f"Connection to {settings.obfuscated_elasticsearch()} is not ready. "
+            f"Tried {event['tries']} times. Retrying..."
+        )
+
+    @backoff.on_exception(
+        lambda: backoff.constant(interval=15),
+        ConfigError,
+        max_time=60,
+        on_backoff=_on_backoff,
+    )
+    def _setup_elasticsearch():
         try:
-            es_wrapper = ElasticsearchBackend.get_instance()
-            dataset_records: DatasetRecordsDAO = DatasetRecordsDAO(es_wrapper)
+            backend = GenericElasticEngineBackend.get_instance()
+            dataset_records: DatasetRecordsDAO = DatasetRecordsDAO(backend)
             datasets: DatasetsDAO = DatasetsDAO.get_instance(
-                es_wrapper, records_dao=dataset_records
+                es=backend,
+                records_dao=dataset_records,
             )
             datasets.init()
             dataset_records.init()
@@ -109,6 +153,10 @@ def configure_app_storage(app: FastAPI):
                 "Once you have verified this, restart the argilla server.\n"
             ) from error
 
+    @app.on_event("startup")
+    async def setup_elasticsearch():
+        _setup_elasticsearch()
+
 
 def configure_app_security(app: FastAPI):
 
@@ -121,17 +169,6 @@ def configure_app_logging(app: FastAPI):
     app.on_event("startup")(configure_logging)
 
 
-app = FastAPI(
-    title="argilla",
-    description="argilla API",
-    # Disable default openapi configuration
-    openapi_url="/api/docs/spec.json",
-    docs_url="/api/docs" if settings.docs_enabled else None,
-    redoc_url=None,
-    version=str(argilla_version),
-)
-
-
 def configure_telemetry(app):
     message = "\n"
     message += inspect.cleandoc(
@@ -160,6 +197,23 @@ def configure_telemetry(app):
             print(message, flush=True)
 
 
+argilla_app = FastAPI(
+    title="Argilla",
+    description="Argilla API",
+    # Disable default openapi configuration
+    openapi_url="/api/docs/spec.json",
+    docs_url="/api/docs" if settings.docs_enabled else None,
+    redoc_url=None,
+    version=str(argilla_version),
+)
+
+app = FastAPI()
+app.mount(settings.base_url, argilla_app)
+
+configure_app_logging(app)
+configure_storage(app)
+configure_telemetry(app)
+
 for app_configure in [
     configure_app_logging,
     configure_middleware,
@@ -167,7 +221,5 @@ for app_configure in [
     configure_app_security,
     configure_api_router,
     configure_app_statics,
-    configure_app_storage,
-    configure_telemetry,
 ]:
-    app_configure(app)
+    app_configure(argilla_app)
